@@ -18,8 +18,6 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 # USA
 
-from __future__ import absolute_import
-
 # support overrides in different directories than our gi module
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -61,6 +59,8 @@ _gobject.pygobject_version = _gi.pygobject_version
 version_info = _gi.pygobject_version[:]
 __version__ = "{0}.{1}.{2}".format(*version_info)
 
+_gi.register_foreign()
+
 
 class _DummyStaticModule(types.ModuleType):
     __path__ = None
@@ -108,12 +108,8 @@ def require_version(namespace, version):
     """
     repository = Repository.get_default()
 
-    if sys.version_info[0] <= 2:
-        if not isinstance(version, basestring):
-            raise ValueError('Namespace version needs to be a string.')
-    else:
-        if not isinstance(version, str):
-            raise ValueError('Namespace version needs to be a string.')
+    if not isinstance(version, str):
+        raise ValueError('Namespace version needs to be a string.')
 
     if namespace in repository.get_loaded_namespaces():
         loaded_version = repository.get_version(namespace)
