@@ -1066,11 +1066,15 @@ static void
 pygobject__g_instance_init(GTypeInstance   *instance,
                            gpointer         g_class)
 {
-    GObject *object = (GObject *) instance;
+    GObject *object;
     PyObject *wrapper, *result;
     PyGILState_STATE state;
     gboolean needs_init = FALSE;
 
+    g_return_if_fail(G_IS_OBJECT(instance));
+
+    object = (GObject *) instance;
+
     wrapper = g_object_get_qdata(object, pygobject_wrapper_key);
     if (wrapper == NULL) {
         wrapper = pygobject_init_wrapper_get();
@@ -1738,6 +1742,7 @@ _wrap_pyg_register_interface_info (PyObject *self, PyObject *args)
     info->interface_init = (GInterfaceInitFunc) initialize_interface;
 
     pyg_register_interface_info (g_type, info);
+    g_free (info);
 
     Py_RETURN_NONE;
 }
@@ -2522,8 +2527,9 @@ PYGI_MODINIT_FUNC PyInit__gi(void) {
     module = PyModule_Create(&__gimodule);
     PyObject *module_dict = PyModule_GetDict (module);
 
-#if PY_VERSION_HEX < 0x03090000
+#if PY_VERSION_HEX < 0x03090000 || defined(PYPY_VERSION)
     /* Deprecated since 3.9 */
+    /* Except in PyPy it's still not a no-op: https://foss.heptapod.net/pypy/pypy/-/issues/3691 */
 
     /* Always enable Python threads since we cannot predict which GI repositories
      * might accept Python callbacks run within non-Python threads or might trigger
