@@ -21,10 +21,8 @@
 import warnings
 
 from .._ossighelper import wakeup_on_signal, register_sigint_fallback
-from ..overrides import override, deprecated_init
+from ..overrides import override, deprecated_init, wrap_list_store_sort_func
 from ..module import get_introspection_module
-from .._compat import xrange
-from gi._gi import pygobject_new_full
 from gi import PyGIWarning
 
 from gi.repository import GLib
@@ -48,22 +46,81 @@ Application = override(Application)
 __all__.append('Application')
 
 
+def _warn_init(cls, instead=None):
+
+    def new_init(self, *args, **kwargs):
+        super(cls, self).__init__(*args, **kwargs)
+        name = cls.__module__.rsplit(".", 1)[-1] + "." + cls.__name__
+        if instead:
+            warnings.warn(
+                ("%s shouldn't be instantiated directly, "
+                 "use %s instead." % (name, instead)),
+                PyGIWarning, stacklevel=2)
+        else:
+            warnings.warn(
+                "%s shouldn't be instantiated directly." % (name,),
+                PyGIWarning, stacklevel=2)
+
+    return new_init
+
+
+@override
 class VolumeMonitor(Gio.VolumeMonitor):
-
-    def __init__(self, *args, **kwargs):
-        super(VolumeMonitor, self).__init__(*args, **kwargs)
-
-        # https://bugzilla.gnome.org/show_bug.cgi?id=744690
-        warnings.warn(
-            "Gio.VolumeMonitor shouldn't be instantiated directly, "
-            "use Gio.VolumeMonitor.get() instead.",
-            PyGIWarning, stacklevel=2)
+    # https://bugzilla.gnome.org/show_bug.cgi?id=744690
+    __init__ = _warn_init(Gio.VolumeMonitor, "Gio.VolumeMonitor.get()")
 
 
-VolumeMonitor = override(VolumeMonitor)
 __all__.append('VolumeMonitor')
 
 
+@override
+class DBusAnnotationInfo(Gio.DBusAnnotationInfo):
+    __init__ = _warn_init(Gio.DBusAnnotationInfo)
+
+
+__all__.append('DBusAnnotationInfo')
+
+
+@override
+class DBusArgInfo(Gio.DBusArgInfo):
+    __init__ = _warn_init(Gio.DBusArgInfo)
+
+
+__all__.append('DBusArgInfo')
+
+
+@override
+class DBusMethodInfo(Gio.DBusMethodInfo):
+    __init__ = _warn_init(Gio.DBusMethodInfo)
+
+
+__all__.append('DBusMethodInfo')
+
+
+@override
+class DBusSignalInfo(Gio.DBusSignalInfo):
+    __init__ = _warn_init(Gio.DBusSignalInfo)
+
+
+__all__.append('DBusSignalInfo')
+
+
+@override
+class DBusInterfaceInfo(Gio.DBusInterfaceInfo):
+    __init__ = _warn_init(Gio.DBusInterfaceInfo)
+
+
+__all__.append('DBusInterfaceInfo')
+
+
+@override
+class DBusNodeInfo(Gio.DBusNodeInfo):
+    __init__ = _warn_init(Gio.DBusNodeInfo)
+
+
+__all__.append('DBusNodeInfo')
+
+
 class ActionMap(Gio.ActionMap):
     def add_action_entries(self, entries, user_data=None):
         """
@@ -368,7 +425,7 @@ class ListModel(Gio.ListModel):
 
     def __getitem__(self, key):
         if isinstance(key, slice):
-            return [self.get_item(i) for i in xrange(*key.indices(len(self)))]
+            return [self.get_item(i) for i in range(*key.indices(len(self)))]
         elif isinstance(key, int):
             if key < 0:
                 key += len(self)
@@ -395,7 +452,7 @@ class ListModel(Gio.ListModel):
         return self.get_n_items()
 
     def __iter__(self):
-        for i in xrange(len(self)):
+        for i in range(len(self)):
             yield self.get_item(i)
 
 
@@ -403,24 +460,27 @@ ListModel = override(ListModel)
 __all__.append('ListModel')
 
 
-def _wrap_list_store_sort_func(func):
-
-    def wrap(a, b, *user_data):
-        a = pygobject_new_full(a, False)
-        b = pygobject_new_full(b, False)
-        return func(a, b, *user_data)
-
-    return wrap
+if (GLib.MAJOR_VERSION, GLib.MINOR_VERSION, GLib.MICRO_VERSION) < (2, 57, 1):
+    # The "additions" functionality in splice() was broken in older glib
+    # https://bugzilla.gnome.org/show_bug.cgi?id=795307
+    # This is a slower fallback which emits a signal per added item
+    def _list_store_splice(self, position, n_removals, additions):
+        self.splice(position, n_removals, [])
+        for v in reversed(additions):
+            self.insert(position, v)
+else:
+    def _list_store_splice(self, position, n_removals, additions):
+        self.splice(position, n_removals, additions)
 
 
 class ListStore(Gio.ListStore):
 
     def sort(self, compare_func, *user_data):
-        compare_func = _wrap_list_store_sort_func(compare_func)
+        compare_func = wrap_list_store_sort_func(compare_func)
         return super(ListStore, self).sort(compare_func, *user_data)
 
     def insert_sorted(self, item, compare_func, *user_data):
-        compare_func = _wrap_list_store_sort_func(compare_func)
+        compare_func = wrap_list_store_sort_func(compare_func)
         return super(ListStore, self).insert_sorted(
             item, compare_func, *user_data)
 
@@ -428,11 +488,11 @@ class ListStore(Gio.ListStore):
         if isinstance(key, slice):
             start, stop, step = key.indices(len(self))
             if step == 1:
-                self.splice(start, max(stop - start, 0), [])
+                _list_store_splice(self, start, max(stop - start, 0), [])
             elif step == -1:
-                self.splice(stop + 1, max(start - stop, 0), [])
+                _list_store_splice(self, stop + 1, max(start - stop, 0), [])
             else:
-                for i in sorted(xrange(start, stop, step), reverse=True):
+                for i in sorted(range(start, stop, step), reverse=True):
                     self.remove(i)
         elif isinstance(key, int):
             if key < 0:
@@ -456,16 +516,19 @@ class ListStore(Gio.ListStore):
 
             start, stop, step = key.indices(len(self))
             if step == 1:
-                self.__delitem__(key)
-                for v in reversed(valuelist):
-                    self.insert(start, v)
+                _list_store_splice(
+                    self, start, max(stop - start, 0), valuelist)
             else:
-                indices = list(xrange(start, stop, step))
+                indices = list(range(start, stop, step))
                 if len(indices) != len(valuelist):
                     raise ValueError
-                for i, v in zip(indices, valuelist):
-                    self.remove(i)
-                    self.insert(i, v)
+
+                if step == -1:
+                    _list_store_splice(
+                        self, stop + 1, max(start - stop, 0), valuelist[::-1])
+                else:
+                    for i, v in zip(indices, valuelist):
+                        _list_store_splice(self, i, 1, [v])
         elif isinstance(key, int):
             if key < 0:
                 key += len(self)
@@ -478,8 +541,7 @@ class ListStore(Gio.ListStore):
                     "Expected type %s.%s" % (
                         pytype.__module__, pytype.__name__))
 
-            self.remove(key)
-            self.insert(key, value)
+            _list_store_splice(self, key, 1, [value])
         else:
             raise TypeError
 
