@@ -1862,6 +1862,7 @@ _pygi_g_registered_type_info_check_object (GIRegisteredTypeInfo *info,
 
         object_type = (PyTypeObject *) PyObject_Type (object);
         if (object_type == NULL) {
+            g_free (type_name_expected);
             return -1;
         }
 
@@ -2269,7 +2270,7 @@ int
 pygi_info_register_types (PyObject *m)
 {
 #define _PyGI_REGISTER_TYPE(m, type, cname, base) \
-    Py_TYPE(&type) = &PyType_Type; \
+    Py_SET_TYPE(&type, &PyType_Type); \
     type.tp_flags = (Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE); \
     type.tp_weaklistoffset = offsetof(PyGIBaseInfo, inst_weakreflist); \
     type.tp_methods = _PyGI##cname##_methods; \
@@ -2282,7 +2283,7 @@ pygi_info_register_types (PyObject *m)
         return -1; \
     };
 
-    Py_TYPE(&PyGIBaseInfo_Type) = &PyType_Type;
+    Py_SET_TYPE(&PyGIBaseInfo_Type, &PyType_Type);
 
     PyGIBaseInfo_Type.tp_dealloc = (destructor) _base_info_dealloc;
     PyGIBaseInfo_Type.tp_repr = (reprfunc) _base_info_repr;
