@@ -20,7 +20,9 @@
 #ifndef __PYGI_MARSHAL_CLEANUP_H__
 #define __PYGI_MARSHAL_CLEANUP_H__
 
-#include "pygi-private.h"
+#include "pygi-struct.h"
+#include "pygi-invoke-state-struct.h"
+#include "pygi-cache.h"
 
 G_BEGIN_DECLS
 
