@@ -235,10 +235,15 @@ pygi_arg_gobject_to_py (GIArgument *arg, GITransfer transfer) {
         if (transfer == GI_TRANSFER_EVERYTHING)
             g_param_spec_unref (arg->v_pointer);
 
-    } else {
+    } else if (G_IS_OBJECT(arg->v_pointer)) {
          pyobj = pygobject_new_full (arg->v_pointer,
                                      /*steal=*/ transfer == GI_TRANSFER_EVERYTHING,
                                      /*type=*/  NULL);
+    } else {
+        PyErr_Format(PyExc_TypeError,
+                     "No means to translate argument or return value for '%s'",
+                     g_type_name_from_instance(arg->v_pointer));
+        return NULL;
     }
 
     return pyobj;
@@ -261,7 +266,7 @@ pygi_arg_gobject_to_py_called_from_c (GIArgument *arg,
      */
     if (arg->v_pointer != NULL &&
             transfer == GI_TRANSFER_NOTHING &&
-            !G_IS_PARAM_SPEC (arg->v_pointer) &&
+            G_IS_OBJECT (arg->v_pointer) &&
             g_object_is_floating (arg->v_pointer)) {
 
         g_object_ref (arg->v_pointer);
