@@ -343,6 +343,7 @@ enum
 {
     SIGNAL_0,
     ACTION_SIGNAL,
+    ACTION2_SIGNAL,
     LAST_SIGNAL
 };
 
@@ -356,6 +357,12 @@ regress_test_action_do_action (RegressTestAction *self)
     return ret;
 }
 
+static RegressTestAction *
+regress_test_action_do_action2 (RegressTestAction *self)
+{
+    return NULL;
+}
+
 static void
 regress_test_action_init (RegressTestAction *self)
 {
@@ -375,4 +382,17 @@ static void regress_test_action_class_init (RegressTestActionClass *klass)
         G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
         G_CALLBACK (regress_test_action_do_action), NULL, NULL,
         NULL, regress_test_action_get_type (), 0);
+
+    /**
+     * RegressTestAction::action2:
+     *
+     * Another action signal.
+     *
+     * Returns: (transfer full): another #RegressTestAction
+     */
+    regress_test_action_signals[ACTION2_SIGNAL] =
+        g_signal_new_class_handler ("action2",
+        G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+        G_CALLBACK (regress_test_action_do_action2), NULL, NULL,
+        NULL, regress_test_action_get_type (), 0);
 }
