@@ -7,9 +7,10 @@ GLib = pytest.importorskip("gi.repository.GLib")
 GObject = pytest.importorskip("gi.repository.GObject")
 Gio = pytest.importorskip("gi.repository.Gio")
 
-
 from .helper import capture_exceptions
 
+GTK4 = (Gtk._version == "4.0")
+
 
 def new_gtype_name(_count=[0]):
     _count[0] += 1
@@ -534,7 +535,7 @@ def test_internal_child():
       <template class="{0}" parent="GtkBox">
         <child>
           <object class="GtkBox" id="somechild">
-            <property name="margin">42</property>
+            <property name="margin-top">42</property>
           </object>
         </child>
       </template>
@@ -548,7 +549,7 @@ def test_internal_child():
         somechild = Gtk.Template.Child(internal=True)
 
     thing = MainThing()
-    assert thing.somechild.props.margin == 42
+    assert thing.somechild.props.margin_top == 42
 
     other_type_name = new_gtype_name()
 
@@ -559,7 +560,7 @@ def test_internal_child():
           <object class="{1}">
             <child internal-child="somechild">
               <object class="GtkBox">
-                <property name="margin">24</property>
+                <property name="margin-top">24</property>
                 <child>
                   <object class="GtkLabel">
                     <property name="label">foo</property>
@@ -578,12 +579,26 @@ def test_internal_child():
         __gtype_name__ = other_type_name
 
     other = OtherThing()
-    child = other.get_children()[0]
+    if not GTK4:
+        child = other.get_children()[0]
+    else:
+        child = other.get_first_child()
+
     assert isinstance(child, MainThing)
-    child = child.get_children()[0]
+
+    if not GTK4:
+        child = child.get_children()[0]
+    else:
+        child = child.get_first_child()
+
     assert isinstance(child, Gtk.Box)
-    assert child.props.margin == 24
-    child = child.get_children()[0]
+    assert child.props.margin_top == 24
+
+    if not GTK4:
+        child = child.get_children()[0]
+    else:
+        child = child.get_first_child()
+
     assert isinstance(child, Gtk.Label)
     assert child.props.label == "foo"
 
@@ -655,7 +670,12 @@ def test_template_hierarchy():
 
             assert isinstance(self._testbox, TestBox)
             assert isinstance(self._testlabel, TestLabel)
-            assert len(self._testbox.get_children()) == 2
+            if not GTK4:
+                children = self._testbox.get_children()
+            else:
+                children = list(self._testbox)
+
+            assert len(children) == 2
 
     win = MyWindow()
     assert isinstance(win, MyWindow)
@@ -685,8 +705,17 @@ def test_multiple_init_template_calls():
 
     my_box = MyBox()
     assert isinstance(my_box, MyBox)
-    assert len(my_box.get_children()) == 1
+    if not GTK4:
+        children = my_box.get_children()
+    else:
+        children = list(my_box)
 
+    assert len(children) == 1
     my_box.init_template()
     assert isinstance(my_box, MyBox)
-    assert len(my_box.get_children()) == 1
+    if not GTK4:
+        children = my_box.get_children()
+    else:
+        children = list(my_box)
+
+    assert len(children) == 1
